@@ -2,47 +2,42 @@ package Gtk2::Ex::DbLinker::AbDataManager;
 use  Gtk2::Ex::DbLinker::DbTools;
 our $VERSION = $Gtk2::Ex::DbLinker::DbTools::VERSION;
 
-use Class::Interface;
-  
-&interface();
 use strict;
 use warnings;
 
-# use Class::AccessorMaker {page => 1,  rec_per_page => 1 }, "no_new";
+sub set_row_pos{}
 
-sub set_row_pos;
+sub get_row_pos{}
 
-sub get_row_pos;
+sub query{}
 
-sub query;
+sub set_field{}
 
-sub set_field;
+sub get_field{}
 
-sub get_field;
+sub get_field_type{}
 
-sub get_field_type;
+sub new_row{}
 
-sub new_row;
+sub save{}
 
-sub save;
+sub delete{}
 
-sub delete;
+sub next{}
 
-sub next;
+sub previous{}
 
-sub previous;
+sub last{}
 
-sub last;
+sub first{}
 
-sub first;
+sub row_count{}
 
-sub row_count;
+sub get_field_names{}
 
-sub get_field_names;
+sub get_autoinc_primarykeys{}
 
-sub get_autoinc_primarykeys;
-
-sub get_primarykeys;
+sub get_primarykeys{}
 
 1;
 
