@@ -1,35 +1,31 @@
 package Gtk2::Ex::DbLinker::RdbDataManager;
 use  Gtk2::Ex::DbLinker::DbTools;
 our $VERSION = $Gtk2::Ex::DbLinker::DbTools::VERSION;
-
-use Class::Interface;
-
-&implements('Gtk2::Ex::DbLinker::AbDataManager');
-
 use strict;
 use warnings;
+use interface qw(Gtk2::Ex::DbLinker::AbDataManager);
 use  Carp;
 use Data::Dumper;
 
-$Class::Interface::CONFESS = 1;
-
 #$self->{data} holds an array of objects returned by the Rose::DB::Manager's descendant
 #This array is access at set_row_pos( $pos ) when get_field( $id ) is called.
 #It is walked by changing $pos, and any changes in the rows, even if the changes affect the selection criteria
 #are not reflected in number of rows in the array.
 #
 sub new {
-	 my ( $class, $req ) = @_;
+	 my $class = shift;
+	my %def = (page=>1, rec_per_page=>1);
+	my %arg = (ref $_[0] eq "HASH" ? (%def, %{$_[0]}) : (%def, @_));
 	my $self = {
-		page => $$req{pate} || 1,
-		rec_per_page => $$req{rec_per_page} || 1,
-		data => $$req{data},
-		meta => $$req{meta},
-		columns => $$req{columns},
-		'+columns' => $$req{'+columns'},
-		primary_keys => $$req{primary_keys},
-	 	ai_primary_keys => $$req{ai_primary_keys},
-		defaults => $$req{defaults},
+		page => $arg{page},
+		rec_per_page => $arg{rec_per_page},
+		data => $arg{data},
+		meta => $arg{meta},
+		columns => $arg{columns},
+		'+columns' => $arg{'+columns'},
+		primary_keys => $arg{primary_keys},
+	 	ai_primary_keys => $arg{ai_primary_keys},
+		defaults => $arg{defaults},
 
 	 };
 	 $self->{log} = Log::Log4perl->get_logger("Gtk2::Ex::DbLinker::RdbDataManager");
@@ -419,32 +415,32 @@ use a Rose::DB::Object::Manager derived object to get a array of Rose::DB::Objec
 
 Pass this object to the RdbDataManager constructor with a Rose::DB::Object::Metatdata derived object
 
- 	my $rdbm = Gtk2::Ex::DbLinker::RdbDataManager->new({data => $data,
+ 	my $rdbm = Gtk2::Ex::DbLinker::RdbDataManager->new(data => $data,
  		meta => Rdb::Mytable->meta,
-	});
+	);
 
 =back
 
 To link the data with a Gtk window, the Gtk entries id in the glade file have to be set to the names of the database fields
 
-	  $self->{linker} = Gtk2::Ex::DbLinker::Form->new({ 
+	  $self->{linker} = Gtk2::Ex::DbLinker::Form->new( 
 		    data_manager => $rdbm,
 		    builder =>  $builder,
 		    rec_spinner => $self->{dnav}->get_object('RecordSpinner'),
   	    	    status_label=>  $self->{dnav}->get_object('lbl_RecordStatus'),
 		    rec_count_label => $self->{dnav}->get_object("lbl_recordCount"),
-	    });
+	    );
 
 To add a combo box in the form, the first field given in fields array will be used as the return value of the combo. 
 noed is the Gtk2combo id in the glade file and the field's name in the table that received the combo values.
 	 
-	my $dman = Gtk2::Ex::DbLinker::RdbDataManager->new({data => Rdb::Combodata::Manager->get_combodata(sort_by => 'name' ), meta => Rdb::Combodata->meta });
+	my $dman = Gtk2::Ex::DbLinker::RdbDataManager->new(data => Rdb::Combodata::Manager->get_combodata(sort_by => 'name' ), meta => Rdb::Combodata->meta );
 
-	$self->{linker}->add_combo({
+	$self->{linker}->add_combo(
     	data_manager => $dman,
     	id => 'comboid',
 	fields => ["id", "name"],
-      });
+      );
 
 And when all combos or datasheets are added:
 
@@ -473,15 +469,18 @@ A new instance is created using an array of objects issue by a Rose::DB::Object:
 
 =head2 constructor
 
-The parameters are passed in a hash reference with the keys C<data> and C<meta>.
+The parameters are passed as a list of parameters name => value, or as a hash reference with the parameters name as keys. 
+
+Parameters are C<data>, C<meta>, C<columns> or  C<'+columns'>.
+
 The value for C<data> is a reference to an array of Rose::SB::Object::Manager derived objects. The value for C<meta> is the corresponding metadata object.
 
 		my $data = Rdb::Mytable::Manager->get_mytable(query => [pk_field => {eq => $value }]);
-		my $dman = Gtk2::Ex::DbLinker::RdbDataManager->new({data=> $data, meta => Rdb::Mytable->meta });
+		my $dman = Gtk2::Ex::DbLinker::RdbDataManager->new(data=> $data, meta => Rdb::Mytable->meta );
 
 Array references of primary key names and auto incremented primary keys may also be passed using  C<primary_keys>, C<ai_primary_keys> as hash keys. If not given the RdbDataManager uses the metadata to have these.
 
-You may pass a C<columns> or  C<'+columns'> as a hash ref where the keys are the names of the relationship and the values are an array ref holding the fields names accessed by this relationship.
+You may pass a C<columns> or  C<'+columns'> parameters. The value is as a hash ref where the keys are the names of the relationship and the values are an array ref holding the fields names accessed by this relationship.
 Use C<+columns> if you are using fields from the main table and from joined table(s). Use C<columns> if you are interested only in fields from tables bounded by join clauses.
 Use neither of them if you want to access fields from the main table only, the relationship being used to restrict the rows.
 The fields selected with C<'+columns'> or with C<'columns'> are readonly: a call to set_field($field_id, $field_value) will not change any value.
@@ -489,7 +488,7 @@ The fields selected with C<'+columns'> or with C<'columns'> are readonly: a call
 =head2 C<query( $data );>
 
 To display an other set of rows in a form, call the query method on the datamanager instance for this form with a new array of Rose::DB::Object derived objects.
-Return 0 if there is no row or 1 on if there are any.
+Return 0 if there is no row or 1 if there are any.
 
 	my $data =  Rdb::Mytable::Manager->get_mytable(query => [pk_field => {eq => $value}]);
 	$self->{form_a}->get_data_manager->query($data);
