@@ -24,10 +24,13 @@ my %fieldtype = (tinyint => "integer", "int" => "integer");
 # -> batch : store the batch_size values of one  (or more) pks for the current subset
 #
 sub new {
-	my ($class, $req) = @_;
+	my %def = (batch_size=>1,pkvalues_filter=>0);
+	my $class = shift;
+	my %args = (%def, @_);
+	#die Dumper(%args);
 	my $self = {
-		batch_size=> $$req{aperture} || 1,
-		pkvalues_filter => $$req{pkvalues_filter} || 0,
+		batch_size=> $args{aperture} || $def{batch_size},
+		pkvalues_filter => $args{pkvalues_filter} || $def{pkvalues_filter},
 	};
       $self->{cols} = [];
        $self->{hcols}= {};
@@ -393,11 +396,13 @@ sub _assemble_new_record {
         if ( $default && $self->{server} =~ /microsoft/i ) {
             $default = $self->parse_sql_server_default( $default );
         }
+	$self->{log}->debug("set database's default value ", $self->{defaults}->{$fieldname}, " for field ", $fieldname );
         $new_record->{$fieldname} = $default;
     }
     
     # ... and then we set user-defined defaults
     foreach my $fieldname ( keys %{$self->{defaults}} ) {
+	$self->{log}->debug("set user's default value ", $self->{defaults}->{$fieldname}, " for field ", $fieldname );
         $new_record->{$fieldname} = $self->{defaults}->{$fieldname};
     }
     return $new_record;
@@ -514,9 +519,11 @@ sub _use_sth_info {
 		8=>'integer', 9=>'date', 10=>'date', 11=>'date', 12=>'varchar', -1=>'varchar', -2=>'boolean', -3=>'boolean', -4 =>'text',
 		-5=>'integer', -6=>'integer', -7=>'integer');
 	for my $name ( @{$self->{cols} }) {
-		my $type = lc $type[$pos++];;
-		if ($self->{server}) { #mysql gives type as given in sqltype above, DBI::CSV (where $self->{server} is undef) gives the type as an array of string
-			$type =  $sqltype{$type};
+		my $type = lc $type[$pos++];
+		#$self->{log}->debug("searching " . $type);
+		#if ($self->{server}){
+	         if ($type =~ /-?\d{1,2}/) { #mysql gives type as given in sqltype above, DBI::CSV (where $self->{server} is undef) gives the type as an array of string
+			 $type =  $sqltype{$type};
 		}
 	
 		$self->{log}->debug($name . " type: " . $type );
