@@ -1,17 +1,11 @@
 package Gtk2::Ex::DbLinker::SqlADataManager;
 use  Gtk2::Ex::DbLinker::DbTools;
 our $VERSION = $Gtk2::Ex::DbLinker::DbTools::VERSION;
-
-use Class::Interface;
-
-&implements('Gtk2::Ex::DbLinker::AbDataManager');
-
 use strict;
 use warnings;
+use interface qw(Gtk2::Ex::DbLinker::AbDataManager);
 use  Carp qw(carp croak confess cluck);
 use Data::Dumper;
-$Class::Interface::CONFESS = 1;
-
 use SQL::Abstract::More;
 use Try::Tiny;
 
@@ -31,23 +25,39 @@ use base qw(Gtk2::Ex::DbLinker::Recordset);
 #slice_position est la position dans le keyset en cours
 #
 sub new {
-	my ( $class, $req ) = @_;
+	my $class = shift;
+	my %arg;
+	#die ref $_[0];
+	my %def = (bla=>1);
+=for comment
+	if ( ref $_[0] eq "HASH" ) {
+		%arg =(%def, %{$_[0]});
+	} elsif (ref $_[0]) {
+		confess __PACKAGE__ . "->new : received arguments of the wrong type. Must be a list or a Hash ref\n";
+	}
+	else {
+		%arg = @_;
+	}
+=cut
+        %arg = (ref $_[0] eq "HASH" ? 	(%def, %{$_[0]}) : (%def, @_));
+	#my ( $class, $req ) = @_;
   		
-	my $self = $class->SUPER::new({aperture => $$req{aperture}, pkvalues_filter=> 1});
+	#my $self = $class->SUPER::new({aperture => $$req{aperture}, pkvalues_filter=> 1});
+	my $self = $class->SUPER::new(batch_size => $arg{aperture}, pkvalues_filter=> 1);
 
-		$$self{dbh} = $$req{dbh};                                  # A database handle
-    		$$self{primary_keys}= $$req{primary_keys};                         # An array ref of primary keys
+		$$self{dbh} = $arg{dbh};                                  # A database handle
+    		$$self{primary_keys}= $arg{primary_keys};                         # An array ref of primary keys
 		#sql                     => $$req{sql},                                  # A hash of SQL related stuff
-		$$self{new_param}= $$req{new_param}; # hash ref of parameters for the SQL::Abstract::More contructor
-		$$self{select_param} = $$req{select_param};  #needed to define the fields and the primary key, can select an empty recordset
+		$$self{new_param}= $arg{new_param}; # hash ref of parameters for the SQL::Abstract::More contructor
+		$$self{select_param} = $arg{select_param};  #needed to define the fields and the primary key, can select an empty recordset
 		#$$self{aperture	=> $$req{aperture} || 1, #batch size : how many records are read by fetch_new_slice
- 		$$self{before_query} = $$req{before_query};
-		$$self{defaults} = $$req{defaults};
+ 		$$self{before_query} = $arg{before_query};
+		$$self{defaults} = $arg{defaults};
 
 
         # $self->{rs} = Gtk2::Ex::DbLinker::Recordset->new( $self->{aperture} );
 	confess ( __PACKAGE__ . ": select_param required") unless ($self->{select_param}); 
-	$self->{ai_primary_key} = $$req{ai_primary_key} if (exists ($$req{ai_primary_key})); 	# an array of auto incremented primary keys 
+	$self->{ai_primary_key} = $arg{ai_primary_key} if (exists ($arg{ai_primary_key})); 	# an array of auto incremented primary keys 
 	#bless $self, $class;
 	 $self->{log} = Log::Log4perl->get_logger(__PACKAGE__);
 	 
@@ -116,8 +126,10 @@ sub new {
 #keyset is an array ref, of arrays, each reccord fetch by query is remembered by an array of the primary key(s) value(s). Most of the time, the array will have one element.
 #If query return 10 records, keyset will refer to an array of 10 arrays
 sub query {
-	 my ( $self,  $where ) = @_;
-	 #my %args = %{$select};
+	#my ( $self,  $where ) = @_;
+	my $self = shift;
+	 my %h;
+	 my $where = (ref $_[0] eq "HASH")? $_[0] : (%h =( @_)) && \%h;
 	 my $select = $self->{select_param};
 	 my $col = $select->{-columns}; #could be undef, default to '*' 
 	 #my $worig = $self->{select_param}->{-where};
@@ -241,7 +253,19 @@ sub _get_rows_from_batch {
 
 sub save {
 
-	my ($self,  $href) = @_;
+	# my ($self,  $href) = @_;
+	my $self = shift;
+	my %h;
+	 my $href = (ref $_[0] eq "HASH" ? $_[0] : (%h = (@_)) && \%h);
+=for comment
+	my $href;
+	if (ref $_[0] eq "HASH") {
+	      $href =  $_[0] 
+         } else {
+	     my %h =( @_);
+	     $href = \%h;
+         }
+=cut
     my %new_values;
 	#my @fieldlist = ();
 	#my @bind_values = ();
@@ -257,7 +281,7 @@ sub save {
      my @pk;   
     if ($href) {
     	for my $k (keys %$href) {
-		#$self->{log}->debug("push on bind_values " .  $href->{$k} . " from field " . $k);
+		$self->{log}->debug("add to new_values " .  $href->{$k} . " from field " . $k);
 		#push @bind_values, $href->{$k};
 		#push @fieldlist, $k;
 		$new_values{$k} = $href->{$k};
@@ -285,7 +309,9 @@ my ($value, $stm, @bind);
 	
 	#if ( $sql_fieldname ~~ @pk) {
 	if (grep (/\b$fieldname\b/, @pk)) {
-		$self->{log}->debug("jumping $fieldname because it's a pk");
+		my @keys = keys %new_values;
+		$self->{log}->debug("Not fetching value from $fieldname because it's a pk. ", 0 + @keys ? "The fetched values come from " . join(" ", @keys) : "");
+
             next;
         }
         
@@ -296,11 +322,12 @@ my ($value, $stm, @bind);
 	    #$self->{log}->debug("push on bind_values " . $fieldname . " : " . $value);
 	    #   push @bind_values, $self->get_field( $fieldname );
 	  #}
+	$self->{log}->debug("field : ", $fieldname, " value : ", (defined $value?$value:""));
         $new_values{$fieldname} = $value;
     }#foreach
     
     # my $update_sql;
-    
+    $self->{log}->debug("new values: ", Dumper %new_values);
     if ( $self->{inserting} ) {
         
 	    #$update_sql = "insert into " . $self->{sql}->{from} . " ( " . join( ",", @fieldlist, ) . " )" . " values ( " . "?," x ( @fieldlist - 1 ) . "? )";
@@ -311,16 +338,18 @@ my ($value, $stm, @bind);
 
         
     } else {
-         $self->{log}->debug("updating ", $table);
+        
 	
 	
 	foreach my $primary_key ( @pk ) {
+		$primary_key=~s/^$table\.//;
 		$value = $self->get_field($primary_key);
-		#$self->{log}->debug("push on bind_values " . $primary_key . " : " . $value);
+		$self->{log}->debug("Get pk " . $primary_key . " value : " . ($value?$value: " !!! undefined !!!"));
 		#push @bind_values,  $self->get_field($primary_key) };
 		$pk_values{$primary_key} = $value;
         }
 
+ 	$self->{log}->debug("updating ", $table, " at rows with pks : ", Dumper %pk_values);
 	 ($stm, @bind) = $self->{sql}->update(-table => $table, -set => \%new_values , -where => \%pk_values);
         
     }
@@ -355,11 +384,12 @@ my ($value, $stm, @bind);
 	#in Recordset, pkvalues is an array ref of array, each array contains usualy one value for the a given row, but can contains 2 values if it's a composed primary key
 	$self->add_pkvalues(\@keys);
 	#$self->{log}->debug( join(", ", @keys) . " added to pkvalues");
-	
-        
+	#turn the flag only if $done is true... otherwise all subsequent atempts to save a new insert that has failed will be treated as updates (not inserts) and will failed also since no pk has been given.
+        $self->{inserting} = 0;
+	$self->{log}->debug("turn off inserting flag");
     }
-    $self->{inserting} = 0;
-    $self->{log}->debug("turn off inserting flag");
+    #$self->{inserting} = 0;
+    #$self->{log}->debug("turn off inserting flag");
     return $done;
 }
 
@@ -516,11 +546,11 @@ See Version in L<Gtk2::Ex::DbLinker::DbTools>
 
 To fetch the data from the database
 
-	  my $rdbm = Gtk2::Ex::DbLinker::SqlADataManager->new({
+	  my $rdbm = Gtk2::Ex::DbLinker::SqlADataManager->new(
 		 	dbh => $dbh,
 		 	 primary_keys => ["pk_id"],
 			select_param =>{-from=>'table', -where=>{id =>{'<'=> 4}}},
-	 });
+	 );
 
 To link the data with a Gtk windows, have the Gtk entries ID, or combo ID in the xml glade file set to the name of the database fields: pk_id, field1, field2...
 
@@ -534,7 +564,7 @@ To link the data with a Gtk windows, have the Gtk entries ID, or combo ID in the
 
 To add a combo box in the form:
 
-	  my $dman = Gtk2::Ex::DbLinker::SqlADataManager->new({
+	  my $dman = Gtk2::Ex::DbLinker::SqlADataManager->new(
 			dbh => $dbh,
 			select_param => {
 				-columns => "id, name",
@@ -542,15 +572,15 @@ To add a combo box in the form:
 				-order_by => [+name]
 				-where => {-bool => "1=1"}
 				},
-		});
+		);
 
 The first field given in the -columns value will be used as the return value of the combo.
 C<noed> is the Gtk2combo id in the glade file and the field's name in the table displayed in the form.
 
-    $self->{linker}->add_combo({
+    $self->{linker}->add_combo(
     	data_manager => $dman,
     	id => 'noed',
-      });
+      );
 
 And when all combos or datasheets are added:
 
@@ -564,8 +594,8 @@ In the subform_a module:
 
 	sub on_pk_changed {
 		 my ($self,$value) = @_;
-		$self->{jrn_coll}->get_data_manager->query({-where =>{pk_value_of_the_bound_table => $value },
-							   });
+		$self->{jrn_coll}->get_data_manager->query(-where =>{pk_value_of_the_bound_table => $value },
+							   );
 		...
 		}
 
@@ -577,7 +607,9 @@ This module fetches data from a dabase using SQL::Abstract::More to build sql st
 
 =head2 constructor
 
-The parameters to C<new> are passed in a hash reference with the keys
+The parameters to C<new> are passed in as a list of parameters name => value or as a hash reference with the parameters name as keys 
+
+Parameters are
 
 =over
 
@@ -626,6 +658,10 @@ If the table use a autogenerated key, use ai_primary_key instead of primary_keys
 
 =item *
 
+C<defaults> : a hash ref of fieldname => default value;
+
+=item *
+
 C<before_query> : a code ref to be run at the start of the query method.
 
 =back
@@ -645,9 +681,9 @@ C<dbh>, C<select_param> are mandatory but you may omit a -where clause to retrie
 							},
 						});
 
-=head2 C<query({ -where => { field => $value} });
+=head2 C<query( -where => { field => $value} );
 
-To display an other set of rows, call the query method on the datamanager instance. The parameter is a hash ref. 
+To display an other set of rows, call the query method on the datamanager instance. The parameter is a list of param => value or a hash ref of the same. 
 The only key is -where and the value follow the same rules of -where parameter in L<SQL::Abstract::More/"select">.
 Return the number of rows. To use the Mysql full text index, use C<{-where => { -bool =>"match(ti, ex, ad) against('+$bla' in boolean mode)" }}>
 
@@ -662,9 +698,9 @@ C<query> will not place the recordset position, but in the above example C<updat
 
 Insert a new record or update an existing record. Fetch the value from auto_incremented primary key.
 
-=head2 C<save({ $field_name => $value });>
+=head2 C<save($field_name => $value );>
 
-Pass a href to save when a value has to be saved in the database without using C< $dman->set_field($ field, $value ) >. Use this when you want to change a field that is part of a multiple fields primary key.
+Pass a list or a hash reference to save when a value has to be saved in the database without using C< $dman->set_field($ field, $value ) >. Use this when you want to change a field that is part of a multiple fields primary key.
 
 =head2 C<new_row();>
 
